@@ -1,5 +1,5 @@
 /*
- * $Id: pam_auth.c,v 1.12 2005/05/17 16:56:25 hno Exp $
+ * $Id: pam_auth.c,v 1.17 2007/07/19 03:36:05 hno Exp $
  *
  * PAM authenticator module for Squid.
  * Copyright (C) 1999,2002,2003 Henrik Nordstrom <hno@squid-cache.org>
@@ -63,6 +63,8 @@
  * Compile this program with: gcc -o pam_auth pam_auth.c -lpam -ldl
  */
 
+#include "util.h"
+
 #include <stdio.h>
 #include <assert.h>
 #include <stdlib.h>
@@ -73,8 +75,6 @@
 
 #include <security/pam_appl.h>
 
-#include "util.h"
-
 #define BUFSIZE 8192
 
 
@@ -100,23 +100,23 @@ static int
 password_conversation(int num_msg, const struct pam_message **msg, struct pam_response **resp, void *appdata_ptr)
 {
     if (num_msg != 1 || msg[0]->msg_style != PAM_PROMPT_ECHO_OFF) {
-	fprintf(stderr, "ERROR: Unexpected PAM converstaion '%d/%s'\n", msg[0]->msg_style, msg[0]->msg);
-	return PAM_CONV_ERR;
+        fprintf(stderr, "ERROR: Unexpected PAM converstaion '%d/%s'\n", msg[0]->msg_style, msg[0]->msg);
+        return PAM_CONV_ERR;
     }
     if (!appdata_ptr) {
-	/* Workaround for Solaris 2.6 where the PAM library is broken
-	 * and does not pass appdata_ptr to the conversation routine
-	 */
-	appdata_ptr = password;
+        /* Workaround for Solaris 2.6 where the PAM library is broken
+         * and does not pass appdata_ptr to the conversation routine
+         */
+        appdata_ptr = password;
     }
     if (!appdata_ptr) {
-	fprintf(stderr, "ERROR: No password available to password_converstation!\n");
-	return PAM_CONV_ERR;
+        fprintf(stderr, "ERROR: No password available to password_converstation!\n");
+        return PAM_CONV_ERR;
     }
     *resp = calloc(num_msg, sizeof(struct pam_response));
     if (!*resp) {
-	fprintf(stderr, "ERROR: Out of memory!\n");
-	return PAM_CONV_ERR;
+        fprintf(stderr, "ERROR: Out of memory!\n");
+        return PAM_CONV_ERR;
     }
     (*resp)[0].resp = strdup((char *) appdata_ptr);
     (*resp)[0].resp_retcode = 0;
@@ -124,8 +124,7 @@ password_conversation(int num_msg, const struct pam_message **msg, struct pam_re
     return ((*resp)[0].resp ? PAM_SUCCESS : PAM_CONV_ERR);
 }
 
-static struct pam_conv conv =
-{
+static struct pam_conv conv = {
     &password_conversation,
     NULL
 };
@@ -152,125 +151,125 @@ main(int argc, char *argv[])
     char buf[BUFSIZE];
     time_t pamh_created = 0;
     int ttl = DEFAULT_SQUID_PAM_TTL;
-    char *service = DEFAULT_SQUID_PAM_SERVICE;
+    const char *service = DEFAULT_SQUID_PAM_SERVICE;
     int no_acct_mgmt = 0;
 
     /* make standard output line buffered */
     setvbuf(stdout, NULL, _IOLBF, 0);
 
     while (1) {
-	int ch = getopt(argc, argv, "1n:t:o");
-	switch (ch) {
-	case -1:
-		goto start;
-	case 'n':
-		service = optarg;
-		break;
-	case 't':
-		ttl = atoi(optarg);
-		break;
-	case '1':
-		ttl = 0;
-		break;
-	case 'o':
-		no_acct_mgmt = 1;
-		break;
-	default:
-		fprintf(stderr, "Unknown getopt value '%c'\n", ch);
-		usage(argv[0]);
-		exit(1);
-	}
+        int ch = getopt(argc, argv, "1n:t:o");
+        switch (ch) {
+        case -1:
+            goto start;
+        case 'n':
+            service = optarg;
+            break;
+        case 't':
+            ttl = atoi(optarg);
+            break;
+        case '1':
+            ttl = 0;
+            break;
+        case 'o':
+            no_acct_mgmt = 1;
+            break;
+        default:
+            fprintf(stderr, "Unknown getopt value '%c'\n", ch);
+            usage(argv[0]);
+            exit(1);
+        }
     }
 start:
     if (optind < argc) {
-	fprintf(stderr, "Unknown option '%s'\n", argv[optind]);
-	usage(argv[0]);
-	exit(1);
+        fprintf(stderr, "Unknown option '%s'\n", argv[optind]);
+        usage(argv[0]);
+        exit(1);
     }
 
     while (fgets(buf, BUFSIZE, stdin)) {
-	user = buf;
-	password = strchr(buf, '\n');
-	if (!password) {
-	    fprintf(stderr, "authenticator: Unexpected input '%s'\n", buf);
-	    goto error;
-	}
-	*password = '\0';
-	password = strchr(buf, ' ');
-	if (!password) {
-	    fprintf(stderr, "authenticator: Unexpected input '%s'\n", buf);
-	    goto error;
-	}
-	*password++ = '\0';
-	rfc1738_unescape(user);
-	rfc1738_unescape(password);
-	conv.appdata_ptr = (char *) password;	/* from buf above. not allocated */
+        user = buf;
+        password = strchr(buf, '\n');
+        if (!password) {
+            fprintf(stderr, "authenticator: Unexpected input '%s'\n", buf);
+            goto error;
+        }
+        *password = '\0';
+        password = strchr(buf, ' ');
+        if (!password) {
+            fprintf(stderr, "authenticator: Unexpected input '%s'\n", buf);
+            goto error;
+        }
+        *password++ = '\0';
+        rfc1738_unescape(user);
+        rfc1738_unescape(password);
+        conv.appdata_ptr = (char *) password;	/* from buf above. not allocated */
 
-	if (ttl == 0) {
-	    /* Create PAM connection */
-	    retval = pam_start(service, user, &conv, &pamh);
-	    if (retval != PAM_SUCCESS) {
-		fprintf(stderr, "ERROR: failed to create PAM authenticator\n");
-		goto error;
-	    }
-	} else if (!pamh || (time(NULL) - pamh_created) >= ttl || pamh_created > time(NULL)) {
-	    /* Close previous PAM connection */
-	    if (pamh) {
-		retval = pam_end(pamh, retval);
-		if (retval != PAM_SUCCESS) {
-		    fprintf(stderr, "WARNING: failed to release PAM authenticator\n");
-		}
-		pamh = NULL;
-	    }
-	    /* Initialize persistent PAM connection */
-	    retval = pam_start(service, "squid@", &conv, &pamh);
-	    if (retval != PAM_SUCCESS) {
-		fprintf(stderr, "ERROR: failed to create PAM authenticator\n");
-		goto error;
-	    }
-	    pamh_created = time(NULL);
-	}
-	/* Authentication */
-	retval = PAM_SUCCESS;
-	if (ttl != 0) {
-	    if (retval == PAM_SUCCESS)
-		retval = pam_set_item(pamh, PAM_USER, user);
-	    if (retval == PAM_SUCCESS)
-		retval = pam_set_item(pamh, PAM_CONV, &conv);
-	}
-	if (retval == PAM_SUCCESS)
-	    retval = pam_authenticate(pamh, 0);
-	if (retval == PAM_SUCCESS && !no_acct_mgmt)
-	    retval = pam_acct_mgmt(pamh, 0);
-	if (retval == PAM_SUCCESS) {
-	    fprintf(stdout, "OK\n");
-	} else {
+        if (ttl == 0) {
+            /* Create PAM connection */
+            retval = pam_start(service, user, &conv, &pamh);
+            if (retval != PAM_SUCCESS) {
+                fprintf(stderr, "ERROR: failed to create PAM authenticator\n");
+                goto error;
+            }
+        } else if (!pamh || (time(NULL) - pamh_created) >= ttl || pamh_created > time(NULL)) {
+            /* Close previous PAM connection */
+            if (pamh) {
+                retval = pam_end(pamh, retval);
+                if (retval != PAM_SUCCESS) {
+                    fprintf(stderr, "WARNING: failed to release PAM authenticator\n");
+                }
+                pamh = NULL;
+            }
+            /* Initialize persistent PAM connection */
+            retval = pam_start(service, "squid@", &conv, &pamh);
+            if (retval != PAM_SUCCESS) {
+                fprintf(stderr, "ERROR: failed to create PAM authenticator\n");
+                goto error;
+            }
+            pamh_created = time(NULL);
+        }
+        /* Authentication */
+        retval = PAM_SUCCESS;
+        if (ttl != 0) {
+            if (retval == PAM_SUCCESS)
+                retval = pam_set_item(pamh, PAM_USER, user);
+            if (retval == PAM_SUCCESS)
+                retval = pam_set_item(pamh, PAM_CONV, &conv);
+        }
+        if (retval == PAM_SUCCESS)
+            retval = pam_authenticate(pamh, 0);
+        if (retval == PAM_SUCCESS && !no_acct_mgmt)
+            retval = pam_acct_mgmt(pamh, 0);
+        if (retval == PAM_SUCCESS) {
+            fprintf(stdout, "OK\n");
+        } else {
 error:
-	    fprintf(stdout, "ERR\n");
-	}
-	/* cleanup */
-	retval = PAM_SUCCESS;
+            fprintf(stdout, "ERR\n");
+        }
+        /* cleanup */
+        retval = PAM_SUCCESS;
 #ifdef PAM_AUTHTOK
-	if (ttl != 0) {
-	    if (retval == PAM_SUCCESS)
-		retval = pam_set_item(pamh, PAM_AUTHTOK, NULL);
-	}
+        if (ttl != 0) {
+            if (retval == PAM_SUCCESS)
+                retval = pam_set_item(pamh, PAM_AUTHTOK, NULL);
+        }
 #endif
-	if (ttl == 0 || retval != PAM_SUCCESS) {
-	    retval = pam_end(pamh, retval);
-	    if (retval != PAM_SUCCESS) {
-		fprintf(stderr, "WARNING: failed to release PAM authenticator\n");
-	    }
-	    pamh = NULL;
-	}
+        if (ttl == 0 || retval != PAM_SUCCESS) {
+            retval = pam_end(pamh, retval);
+            if (retval != PAM_SUCCESS) {
+                fprintf(stderr, "WARNING: failed to release PAM authenticator\n");
+            }
+            pamh = NULL;
+        }
     }
 
     if (pamh) {
-	retval = pam_end(pamh, retval);
-	if (retval != PAM_SUCCESS) {
-	    pamh = NULL;
-	    fprintf(stderr, "ERROR: failed to release PAM authenticator\n");
-	}
+        retval = pam_end(pamh, retval);
+        if (retval != PAM_SUCCESS) {
+            pamh = NULL;
+            fprintf(stderr, "ERROR: failed to release PAM authenticator\n");
+        }
     }
     return 0;
 }
