@@ -1,5 +1,5 @@
 /*
- * $Id: ntlmauth.h,v 1.10 2005/05/17 16:56:35 hno Exp $
+ * $Id: ntlmauth.h,v 1.12 2003/08/05 21:40:04 robertc Exp $
  *
  * * * * * * * * Legal stuff * * * * * * *
  *
@@ -9,12 +9,12 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
- *  
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -33,12 +33,12 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
- *  
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
@@ -54,27 +54,10 @@
 #define SQUID_NTLMAUTH_H
 
 /* int*_t */
-#include "squid_types.h"
+#include "config.h"
 
 /* All of this cruft is little endian */
-#ifdef WORDS_BIGENDIAN
-#define SSWAP(x)	(bswap16((x)))
-#define WSWAP(x)	(bswap32((x)))
-#else
-#define SSWAP(x)	(x)
-#define WSWAP(x)	(x)
-#endif
-
-#ifdef HAVE_BYTESWAP_H
-#include <byteswap.h>
-#define bswap16(x) bswap_16(x)
-#define bswap32(x) bswap_32(x)
-#else	 /* HAVE_BISTWAP_H */
-#define bswap16(x) (((((u_int16_t)x) >> 8) & 0xff) | ((((u_int16_t)x) & 0xff) << 8))
-#define bswap32(x) \
-    (((((u_int32_t)x) & 0xff000000) >> 24) | ((((u_int32_t)x) & 0x00ff0000) >>  8) | \
-     ((((u_int32_t)x) & 0x0000ff00) <<  8) | ((((u_int32_t)x) & 0x000000ff) << 24))
-#endif /* HAVE_BITSWAP_H */
+#include "squid_endian.h"
 
 /* Used internally. Microsoft seems to think this is right, I believe them.
  * Right. */
@@ -173,10 +156,10 @@ typedef struct _ntlm_authenticate {
 } ntlm_authenticate;
 
 const char *ntlm_make_challenge(char *domain, char *domain_controller,
-    unsigned char *challenge_nonce, int challenge_nonce_len);
+                                char *challenge_nonce, int challenge_nonce_len);
 lstring ntlm_fetch_string(char *packet, int32_t length, strhdr * str);
 void ntlm_add_to_payload(char *payload, int *payload_length,
-    strhdr * hdr, char *toadd,
-    int toadd_length, int base_offset);
+                         strhdr * hdr, char *toadd,
+                         int toadd_length, int base_offset);
 
 #endif /* SQUID_NTLMAUTH_H */
