@@ -1,5 +1,5 @@
-#ifndef _SNMP_H_
-#define _SNMP_H_
+#ifndef SQUID_SNMP_H
+#define SQUID_SNMP_H
 
 /*
  * Definitions for the Simple Network Management Protocol (RFC 1067).
@@ -8,9 +8,9 @@
 /**********************************************************************
  *
  *           Copyright 1997 by Carnegie Mellon University
- * 
+ *
  *                       All Rights Reserved
- * 
+ *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
  * provided that the above copyright notice appear in all copies and that
@@ -18,7 +18,7 @@
  * supporting documentation, and that the name of CMU not be
  * used in advertising or publicity pertaining to distribution of the
  * software without specific, written prior permission.
- * 
+ *
  * CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  * ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
  * CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
@@ -26,9 +26,9 @@
  * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
  * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
  * SOFTWARE.
- * 
- * $Id: snmp.h,v 1.13 1998/04/04 01:43:42 kostas Exp $
- * 
+ *
+ * $Id: snmp.h,v 1.16 2003/01/23 00:36:47 robertc Exp $
+ *
  **********************************************************************/
 
 #if HAVE_SYS_TYPES_H
@@ -39,7 +39,9 @@
 #endif
 
 /* These come first */
+#if 0
 #include "asn1.h"
+#endif
 #include "snmp_error.h"
 #if 0
 #include "mibii.h"
@@ -69,7 +71,6 @@
 #endif
 #include "snmp-internal.h"
 #include "parse.h"
-#include "snmp_compat.h"
 #include "snmp_debug.h"
 
-#endif /* _SNMP_H_ */
+#endif /* SQUID_SNMP_H */
